@@ -1,5 +1,5 @@
 use crate::bindings::Windows::Win32::{
-    DisplayDevices::*, Gdi::*, SystemServices::*, WindowsAndMessaging::*,
+    UI::DisplayDevices::*, Graphics::Gdi::*, System::SystemServices::*, UI::WindowsAndMessaging::*,
 };
 use crate::geometry::*;
 
@@ -38,17 +38,17 @@ extern "system" fn get_monitors_proc(
             size: PhysicalSize::new((rc.right - rc.left) as u32, (rc.bottom - rc.top) as u32),
             is_primary: (info.dwFlags & MONITORINFOF_PRIMARY) != 0,
         });
-        BOOL(1)
+        TRUE
     }
 }
 
 /// Return monitors info.
 pub fn get_monitors() -> Vec<Monitor> {
     unsafe {
-        let len = GetSystemMetrics(SYSTEM_METRICS_INDEX::SM_CMONITORS) as usize;
+        let len = GetSystemMetrics(SM_CMONITORS) as usize;
         let mut v = Vec::with_capacity(len);
         EnumDisplayMonitors(
-            HDC(0),
+            HDC::NULL,
             std::ptr::null_mut(),
             Some(get_monitors_proc),
             LPARAM((&mut v) as *mut Vec<Monitor> as _),
@@ -65,9 +65,9 @@ pub fn monitor_from_point(point: ScreenPosition) -> Option<Monitor> {
                 x: point.x,
                 y: point.y,
             },
-            MONITOR_FROM_FLAGS::MONITOR_DEFAULTTONULL,
+            MONITOR_DEFAULTTONULL,
         );
-        if hmonitor == HMONITOR(0) {
+        if hmonitor == HMONITOR::NULL {
             return None;
         }
         let mut info = MONITORINFO {
@@ -96,7 +96,7 @@ mod tests {
         unsafe {
             assert_eq!(
                 monitors.len(),
-                GetSystemMetrics(SYSTEM_METRICS_INDEX::SM_CMONITORS) as usize
+                GetSystemMetrics(SM_CMONITORS) as usize
             );
         }
     }
