@@ -1,6 +1,6 @@
 use crate::bindings::Windows::Win32::{
-    Controls::*, DisplayDevices::*, Gdi::*, HiDpi::*, Intl::*, KeyboardAndMouseInput::*, Shell::*,
-    SystemServices::*, WindowsAndMessaging::*,
+    UI::Controls::*, UI::DisplayDevices::*, Graphics::Gdi::*, UI::HiDpi::*, Globalization::*, UI::KeyboardAndMouseInput::*, UI::Shell::*,
+    System::SystemServices::*, UI::WindowsAndMessaging::*,
 };
 #[cfg(feature = "raw_input")]
 use crate::raw_input;
@@ -155,7 +155,7 @@ pub(crate) extern "system" fn window_proc<T: EventHandler + 'static>(
                     if state.entered_window.is_none() {
                         TrackMouseEvent(&mut TRACKMOUSEEVENT {
                             cbSize: std::mem::size_of::<TRACKMOUSEEVENT>() as _,
-                            dwFlags: TRACKMOUSEEVENT_FLAGS::TME_LEAVE,
+                            dwFlags: TME_LEAVE,
                             hwndTrack: hwnd,
                             dwHoverTime: 0,
                         });
@@ -367,7 +367,7 @@ pub(crate) extern "system" fn window_proc<T: EventHandler + 'static>(
             }
             WM_WINDOWPOSCHANGED => {
                 let pos = &*(lparam.0 as *const WINDOWPOS);
-                if pos.flags.0 & SET_WINDOW_POS_FLAGS::SWP_NOMOVE.0 == 0 {
+                if pos.flags.0 & SWP_NOMOVE.0 == 0 {
                     call_handler(|eh: &mut T, _| {
                         eh.moved(handle, ScreenPosition::new(pos.x, pos.y))
                     });
@@ -393,7 +393,7 @@ pub(crate) extern "system" fn window_proc<T: EventHandler + 'static>(
                     rc.top,
                     rc.right - rc.left,
                     rc.bottom - rc.top,
-                    SET_WINDOW_POS_FLAGS::SWP_NOZORDER | SET_WINDOW_POS_FLAGS::SWP_NOACTIVATE,
+                    SWP_NOZORDER | SWP_NOACTIVATE,
                 );
                 call_handler(|eh: &mut T, _| eh.dpi_changed(handle));
                 LRESULT(0)
@@ -409,8 +409,8 @@ pub(crate) extern "system" fn window_proc<T: EventHandler + 'static>(
                 );
                 let rc = adjust_window_rect(
                     size,
-                    GetWindowLongPtrW(hwnd, WINDOW_LONG_PTR_INDEX::GWL_STYLE) as _,
-                    GetWindowLongPtrW(hwnd, WINDOW_LONG_PTR_INDEX::GWL_EXSTYLE) as _,
+                    GetWindowLongPtrW(hwnd, GWL_STYLE) as _,
+                    GetWindowLongPtrW(hwnd, GWL_EXSTYLE) as _,
                     next_dpi as u32,
                 );
                 let mut ret = (lparam.0 as *mut SIZE).as_mut().unwrap();
@@ -421,12 +421,12 @@ pub(crate) extern "system" fn window_proc<T: EventHandler + 'static>(
             WM_DROPFILES => {
                 let hdrop = HDROP(wparam.0 as _);
                 let file_count =
-                    DragQueryFileW(hdrop, std::u32::MAX, PWSTR(std::ptr::null_mut()), 0);
+                    DragQueryFileW(hdrop, std::u32::MAX, PWSTR::NULL, 0);
                 let mut buffer = Vec::new();
                 let files = (0..file_count)
                     .map(|i| {
                         let len =
-                            DragQueryFileW(hdrop, i, PWSTR(std::ptr::null_mut()), 0) as usize + 1;
+                            DragQueryFileW(hdrop, i, PWSTR::NULL, 0) as usize + 1;
                         buffer.resize(len, 0);
                         DragQueryFileW(hdrop, i, PWSTR(buffer.as_mut_ptr()), len as u32);
                         buffer.pop();
@@ -478,12 +478,7 @@ pub(crate) extern "system" fn window_proc<T: EventHandler + 'static>(
                 match wparam.0 {
                     w if w == UserMessage::SetTitle as usize => {
                         let state = handle.state.read().unwrap();
-                        let s = state
-                            .title
-                            .encode_utf16()
-                            .chain(Some(0))
-                            .collect::<Vec<_>>();
-                        SetWindowTextW(hwnd, PWSTR(s.as_ptr() as _));
+                        SetWindowTextW(hwnd, state.title.as_str());
                     }
                     w if w == UserMessage::SetPosition as usize => {
                         let state = handle.state.read().unwrap();
@@ -494,17 +489,17 @@ pub(crate) extern "system" fn window_proc<T: EventHandler + 'static>(
                             state.set_position.1,
                             0,
                             0,
-                            SET_WINDOW_POS_FLAGS::SWP_NOZORDER
-                                | SET_WINDOW_POS_FLAGS::SWP_NOSIZE
-                                | SET_WINDOW_POS_FLAGS::SWP_NOACTIVATE,
+                            SWP_NOZORDER
+                                | SWP_NOSIZE
+                                | SWP_NOACTIVATE,
                         );
                     }
                     w if w == UserMessage::SetInnerSize as usize => {
                         let state = handle.state.read().unwrap();
                         let rc = adjust_window_rect(
                             state.set_inner_size,
-                            GetWindowLongPtrW(hwnd, WINDOW_LONG_PTR_INDEX::GWL_STYLE) as _,
-                            GetWindowLongPtrW(hwnd, WINDOW_LONG_PTR_INDEX::GWL_EXSTYLE) as _,
+                            GetWindowLongPtrW(hwnd, GWL_STYLE) as _,
+                            GetWindowLongPtrW(hwnd, GWL_EXSTYLE) as _,
                             GetDpiForWindow(hwnd),
                         );
                         SetWindowPos(
@@ -514,9 +509,9 @@ pub(crate) extern "system" fn window_proc<T: EventHandler + 'static>(
                             0,
                             rc.right - rc.left,
                             rc.bottom - rc.top,
-                            SET_WINDOW_POS_FLAGS::SWP_NOZORDER
-                                | SET_WINDOW_POS_FLAGS::SWP_NOMOVE
-                                | SET_WINDOW_POS_FLAGS::SWP_NOACTIVATE,
+                            SWP_NOZORDER
+                                | SWP_NOMOVE
+                                | SWP_NOACTIVATE,
                         );
                     }
                     w if w == UserMessage::EnableIme as usize => {
@@ -536,7 +531,7 @@ pub(crate) extern "system" fn window_proc<T: EventHandler + 'static>(
                             0,
                             GetDpiForWindow(hwnd),
                         );
-                        SetWindowLongPtrW(hwnd, WINDOW_LONG_PTR_INDEX::GWL_STYLE, style as _);
+                        SetWindowLongPtrW(hwnd, GWL_STYLE, style as _);
                         SetWindowPos(
                             hwnd,
                             HWND(0),
@@ -544,11 +539,11 @@ pub(crate) extern "system" fn window_proc<T: EventHandler + 'static>(
                             0,
                             rc.right - rc.left,
                             rc.bottom - rc.top,
-                            SET_WINDOW_POS_FLAGS::SWP_NOMOVE
-                                | SET_WINDOW_POS_FLAGS::SWP_NOZORDER
-                                | SET_WINDOW_POS_FLAGS::SWP_FRAMECHANGED,
+                            SWP_NOMOVE
+                                | SWP_NOZORDER
+                                | SWP_FRAMECHANGED,
                         );
-                        ShowWindow(hwnd, SHOW_WINDOW_CMD::SW_SHOW);
+                        ShowWindow(hwnd, SW_SHOW);
                     }
                     w if w == UserMessage::AcceptDragFiles as usize => {
                         DragAcceptFiles(hwnd, BOOL(lparam.0 as _));
